package com.ruoyi.hezhi.service;

import com.github.pagehelper.PageInfo;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.hezhi.domain.TbStudyCenter;
import com.ruoyi.hezhi.domain.dto.StudyCenterDTO;
import com.ruoyi.hezhi.domain.vo.StudyCenterVO;

import java.util.List;
import java.util.Map;

/**
 * 学习中心Service接口
 *
 * @author ruoyi
 * @date 2024-10-21
 */
public interface ITbStudyCenterService
{
    /**
     * 查询学习中心
     *
     * @param studyCenterId 学习中心主键
     * @return 学习中心
     */
    public TbStudyCenter selectTbStudyCenterByStudyCenterId(Long studyCenterId);

    /**
     * 查询学习中心列表
     *
     * @param tbStudyCenter 学习中心
     * @return 学习中心集合
     */
    public List<TbStudyCenter> selectTbStudyCenterList(TbStudyCenter tbStudyCenter);

    /**
     * 查询学习中心列表
     *
     * @return 学习中心集合
     */
    public List<StudyCenterVO> getAllStudyCenterList();

    /**
     * 新增学习中心
     *
     * @param tbStudyCenter 学习中心
     * @return 结果
     */
    public int insertTbStudyCenter(TbStudyCenter tbStudyCenter);

    /**
     * 修改学习中心
     *
     * @param tbStudyCenter 学习中心
     * @return 结果
     */
    public int updateTbStudyCenter(TbStudyCenter tbStudyCenter);

    /**
     * 批量删除学习中心
     *
     * @param studyCenterIds 需要删除的学习中心主键集合
     * @return 结果
     */
    public int deleteTbStudyCenterByStudyCenterIds(Long[] studyCenterIds);

    /**
     * 删除学习中心信息
     *
     * @param studyCenterId 学习中心主键
     * @return 结果
     */
    public int deleteTbStudyCenterByStudyCenterId(Long studyCenterId);

    /**
     * 学习中心入驻
     *
     * @param studyCenterDTO
     * @return ok
     */
    public AjaxResult joinInStudyCenter(StudyCenterDTO studyCenterDTO);

    /**
     * 学习中心列表
     *
     * @param params 参数
     * @return 学习中心列表
     */
    public List<Map<String, Object>> getStudyCenterList(Map<String, Object> params);

    /**
     * 学习中心详情
     *
     * @param params 参数
     * @return 学习中心详情
     */
    public Map<String, Object> getStudyCenterInfo(Map<String, Object> params);

    public List<Map<String, Object>> getStudyCenterEvaluateAgencyList(Long studyCenterId);

    public PageInfo<Map<String, Object>> getStudyCenterCourseList(Integer pageNum, Integer pageSize, Long studyCenterId, Long evaluateAgencyId);

    StudyCenterVO getNearbyStudyCenter(String latitude, String longitude);
}
